@@ -2,24 +2,26 @@ package Test::OnlySome;
 use 5.012;
 use strict;
 use warnings;
-use Keyword::Declare;
 use Data::Dumper;   # DEBUG
+
 use Carp qw(croak);
+use Keyword::Declare;   # {debug=>1};
+use List::Util::MaybeXS qw(all);
 use Scalar::Util qw(looks_like_number);
 
 use vars;
 use Import::Into;
 
-use constant { true => !!1, false => !!0 };
-
 use parent 'Exporter';
 our @EXPORT = qw( skip_these skip_next );
 
-our $VERSION = '0.000008';
+our $VERSION = '0.001000';
+
+use constant { true => !!1, false => !!0 };
 
 # TODO move $TEST_NUMBER_OS into the options structure.
 
-# Docs {{{3
+# Docs, including osprove and T::OS::RerunFailed example {{{3
 
 =head1 NAME
 
@@ -73,7 +75,7 @@ Then, re-run:
 
 Since test 1 passed the first time, it was skipped the second time.
 
-You don't have to use C<Test::OnlySome::RerunFailed>.  You can directly
+You don't have to use L<Test::OnlySome::RerunFailed>.  You can directly
 use C<Test::OnlySome>, and you can decide in some other way which tests
 you want to skip.
 
@@ -81,6 +83,10 @@ The argument to L</os> can be a statement or block, and it doesn't have to
 be a L<Test::More> test.  You can wrap long-running tests in functions,
 and apply L</os> to those functions.
 
+Please note that L</os> can take a C<test_count> argument.  As discussed
+in more detail below, please use a C<test_count> of 1 for all tests run
+under L<Test::OnlySome::RerunFailed>.
+
 =head1 MARKING TESTS
 
 You can pick which tests to skip using implicit or explicit configuration.
@@ -197,6 +203,14 @@ sub import {
     # going to use for our own purposes below.
     $self->export_to_level($level);
 
+    # Put List::Util::all() in the caller's package so we can use it in
+    # the generated code.  Otherwise, the caller would have to use
+    # List::Util manually.
+    {
+        no strict 'refs';
+        *{ $target . '::__TOS_all' } = \&all;
+    }
+
     # Create the variables we need in the target package
     vars->import::into($target, qw($TEST_NUMBER_OS $TEST_ONLYSOME));
 
@@ -279,9 +293,29 @@ C<< $hashref_options->{n} >>.
 
 =back
 
-CAUTION: The given statement or block will be run in its own lexical scope,
+=head3 Cautions
+
+=over
+
+=item *
+
+The given statement or block will be run in its own lexical scope,
 not in the caller's scope.
 
+=item *
+
+If you use C<< test_count>1 >>, the whole block will be skipped based on
+whether the B<first test> in that block should be skipped.  So, for example,
+
+    os 2 { ok(1); ok(0); }
+
+will skip the C<ok(0)> if the C<ok(1)> is skipped.
+
+=back
+
+I recommend that, when using L<Test::OnlySome::RerunFailed>, you B<not> use
+C<< test_count>1 >>.
+
 =cut
 
     keyword os(String? $debug_var, Var? $opts_name, Num? $N,
@@ -354,19 +388,23 @@ sub _gen {
 
     $N = "$optsVarName$W$L n $R // 1" unless $N;
 
-    my $replacement = qq{
+    my $replacement = qq[
         {
-            my \$ntests = $N;
-            my \$first_test_num = \$TEST_NUMBER_OS;
-            \$TEST_NUMBER_OS += \$ntests;
+            my \$__ntests = $N;
+            my \$__first_test_num = \$TEST_NUMBER_OS;
+            \$TEST_NUMBER_OS += \$__ntests;
+            my \$__skips = $optsVarName$W$L skip $R;
+            my \@__x = (\$__first_test_num .. (\$__first_test_num+\$__ntests-1));
+            # print STDERR 'Tests: ', join(', ', \@__x), "\\n";
+
             SKIP: {
-                # print STDERR " ==> Trying test \$first_test_num\\n"; # DEBUG
-                skip 'Test::OnlySome: you asked me to skip this', \$ntests
-                    if $optsVarName$W$L skip $R$W$L \$first_test_num $R;
+                skip 'Test::OnlySome: you asked me to skip this', \$__ntests
+                    if __TOS_all { \$__skips$W$L \$_ $R } \@__x;
+
                 $code
             }
-        };
-    };
+        }
+    ];
 
     #print STDERR "$replacement\n"; # DEBUG
     return $replacement;
@@ -477,7 +515,6 @@ sub _printtrace {
 
 # }}}2
 # }}}1
-
 # More docs {{{3
 =head1 VARIABLES
 
